@@ -251,7 +251,7 @@ void personal_photo_frame_update_content (PersonalPhotoFrame *self)
 				}
 				gchar *filename = g_strdup (g_dir_read_name (dir));
 				if (!filename) {
-					self->priv->slideshowNum = 1;
+					self->priv->slideshowNum = -1;
 					g_dir_rewind (dir);
 					filename = g_strdup (g_dir_read_name (dir));
 				}
